==> WRSS_2.1.tar.gz: WRSS/man/createRiver.Rd <==
\name{createRiver}
\alias{createRiver}
\title{
Constructor for class of \code{createRiver}
}
\description{
this function constructs an object from class of \code{createRiver}, which is able to act as a chanel or resource to supply a seort of demand(s).
}
\usage{
createRiver(name, downstream, seepageFraction,
            seepageObject, discharge, priority)
}
\arguments{
  \item{name}{(optional) A string: the name of the river}
  \item{downstream}{(optional) An object; from either of classes of \code{\link[WRSS]{createAquifer}} , \code{\link[WRSS]{createRiver}}, \code{\link[WRSS]{createReservoir}}, \code{\link[WRSS]{createJunction}}, \code{\link[WRSS]{createDiversion}}, and \code{\link[WRSS]{createDemandSite}}; which outflow volume pours to it.}
  \item{seepageFraction}{(optional) The seepage coeffcient of river discharge flow. The seepage is computed as the product of \code{seepageFraction} and river discharge. It is in \code{[0, 1]} interval}
  \item{seepageObject}{(optional) An object; from either of classes of \code{\link[WRSS]{createAquifer}} , \code{\link[WRSS]{createRiver}}, \code{\link[WRSS]{createReservoir}}, \code{\link[WRSS]{createJunction}}, \code{\link[WRSS]{createDiversion}}, and \code{\link[WRSS]{createDemandSite}}; which seepage volume pours to it.}
  \item{discharge}{(optional) A vector: is a vector of river discharge time series (MCM).}
  \item{priority}{(optional) An integer: the supplying priority. \code{priority} is a value in [1, 99] interval. If missing, the \code{priority} is set to \code{Inf}.}
}
\value{
An object from class of \code{createRiver}
}
\author{
Rezgar Arabzadeh
}

\seealso{\code{\link[WRSS]{addObjectToArea}}}

\keyword{ list }

==> WRSS_2.3.tar.gz: WRSS/man/createRiver.Rd <==
\name{createRiver}
\alias{createRiver}
\title{
Constructor for class of \code{createRiver}
}
\description{
this function constructs an object from class of \code{createRiver}, which is able to act as a chanel or resource to supply a seort of demand(s).
}
\usage{
createRiver(name, downstream, seepageFraction,
            seepageObject, discharge, priority)
}
\arguments{
  \item{name}{(optional) A string: the name of the river}
  \item{downstream}{(optional) An object; from either of classes of \code{\link[WRSS]{createAquifer}} , \code{\link[WRSS]{createRiver}}, \code{\link[WRSS]{createReservoir}}, \code{\link[WRSS]{createJunction}}, \code{\link[WRSS]{createDiversion}}, or \code{\link[WRSS]{createDemandSite}}; which outflow volume pours to it.}
  \item{seepageFraction}{(optional) The seepage coeffcient of river discharge flow. The seepage is computed as the product of \code{seepageFraction} and river discharge. It is in \code{[0, 1]} interval}
  \item{seepageObject}{(optional) An object; from either of classes of \code{\link[WRSS]{createAquifer}} , \code{\link[WRSS]{createRiver}}, \code{\link[WRSS]{createReservoir}}, \code{\link[WRSS]{createJunction}}, \code{\link[WRSS]{createDiversion}}, or \code{\link[WRSS]{createDemandSite}}; which seepage volume pours to it.}
  \item{discharge}{(optional) A vector: is a vector of river discharge time series (MCM).}
  \item{priority}{(optional) An integer: the supplying priority. \code{priority} is a value in [1, 99] interval. If missing, the \code{priority} is set to \code{Inf}.}
}
\value{
An object from class of \code{createRiver}
}
\author{
Rezgar Arabzadeh
}

\seealso{\code{\link[WRSS]{addObjectToArea}}}

\keyword{ list }
